==> psxc-imdb_v2.1.tgz: psxc-imdb_v2.1/addons/psxc-imdb-nuker.sh <==
#!/bin/bash

# psxc-imdb-nuker
# this script will nuke releases based on imdb score.
#####################################################
#
# This script was last changed with the release of psxc-imdb v2.0k

# Config
########
# Any of the following variables put in psxc-imdb.conf will override what is
# put in here. The only "needed" variable is the variable describing the path
# to psxc-imdb.conf. Fyi.
# After you're done configging, run the script from shell. It will test a
# few variables/settings and report back to you.
#############################################################################

# Version number. No need to change
VERSION=2.1

# The location of psxc-imdb.conf. This is the full path.
IMDB_CONF=/glftpd/etc/psxc-imdb.conf
#IMDB_CONF=/glftpd/bin/psxc-imdb.conf

# What imdb score should be the minimum *allowed* on site? For now no decimals
# is allowed.
MIN_SCORE=5
#MIN_SCORE=6

# Nuke message for score nukes.
MIN_SCORE_MSG="Too low iMDB score"

# On the other hand, you can choose to nuke the release if there is less than
# a certain number of votes on the movie, no matter how high it scored.
NUKE_VOTES=10
#NUKE_VOTES=0

# Nuke message for votes nuke.
NUKE_VOTES_MSG="Too few votes on iMDB"

# Some sites allow only movies after a certain year. Here's an option to
# auto-nuke movies older than the following year.
NUKE_YEAR=2000
#NUKE_YEAR=0

# Nuke message for year nukes.
NUKE_YEAR_MSG="Movie is too old"

# Some people may want to nuke limited releases. Or only allow movies with
# a certain number of screens. Here's a way to do so. Less than the following
# number will be nuked.
NUKE_SCREENS=100
#NUKE_SCREENS=0

# Nuke message for screens nuke.
NUKE_SCREENS_MSG="Limited movies not allowed."

# What should be the multiplier of these nukes?
MULTIPLIER=3
#MULTIPLIER=2

# You can select a number of groups not to nuke here (affils etc). Separate
# the groupname with a space.
NO_NUKE_GROUP="siteops affils"
#NO_NUKE_GROUP=""

# You can also exclude a number of people from being nuked. Separate list by
# a space.
NO_NUKE_USER="sitop pr0nking"
#NO_NUKE_USER=""

# You can also include dirs here which holds the name of all affils. This is
# perhaps the best option as you can add and remove affils dynamically without
# editing this config all the time. The listed groupnames must be directories.
# The dirs listed must be relative to GLROOT in psxc-imdb.conf
NO_NUKE_AFFIL_DIR="/site/AFFILS /site/GROUPS"
#NO_NUKE_AFFIL_DIR=""

# You can also enter a list of groups which release movies you never want to
# nuke, no matter how bad score, votes etc.
NO_NUKE_RELGROUP="CPY QSP"
#NO_NUKE_RELGROUP=""

# If you wish to keep all releases uploaded in certain dirs, enter them here.
# Paths are relative to GLROOT
NO_NUKE_DIR="/site/ARCHIVE /site/PRIVATE"
#NO_NUKE_DIR=""

# The location of glftpd.conf. This is the full path.
GLFTPD_CONF=/glftpd/etc/glftpd.conf
#GLFTPD_CONF=/etc/glftpd.conf

# Since nuking require root privileges, or that the nuker binary has the set-UID-bit
# set (chmod +s /glftpd/bin/nuker), You can instead of performing the nuke in this
# script log the offending dirs to a file. Then you can use a crontab'ed script to
# do the actual nuking, or whatever else you prefer.
# Either set the name of a logfile here, or set this empty to do nukes on the fly.
# Also check NUKE_WARN below.
# The syntax of the logfile is as follows:
# <dir relative to $GLROOT> <multiplier> <message>
#NUKE_LOGFILE="/glftpd/ftp-data/logs/imdb-nukes.log"
NUKE_LOGFILE=""

# Putting the following variables non-empty will stop nuke on the fly - instead, a
# msg will be put in a logfile, using standard glftpd.log format.
# This warning will not stop any logging done to a file in NUKE_LOGFILE
# The file is *not* relative to GLROOT.
# The message uses the following keywords:
# RELNAME   - name of the release directory
# REASON    - the reason why the release will be nuked. See nuke msg's above.
# MOVIENAME - Name of the movie.
# BOLD      - Bold characters on/off.
NUKE_WARN_FILE=/glftpd/ftp-data/logs/glftpd.log
NUKE_WARN_MSG="[ BOLDIMDB NUKEWARNINGBOLD ] : [ BOLDRELNAMEBOLD ] is a nukee - REASON"
NUKE_WARN_TRIGGER="UPDATE:"

# In case you do nuking on the fly, what user should be the one doing the nuking?
# This has got to be a valid user in glftpd's password list.
NUKER_PERSON="sitebot"

# Sometimes an imdb lookup fails. For some moderate protection against this (you
# do not wish to autonuke a release if the imdb script haven't found the data)
# To safeguard from this you should keep the following variable set to 1
NUKE_SAFEGUARD=1
#NUKE_SAFEGUARD=0

# End of config
####################################################################################

# Let's load some variables from psxc-imdb.conf
. $IMDB_CONF

####################################################################################
# The following grabs exported variables. The code is taken from psxc-imdb-parser.sh
# found in the extras/ dir.

IFSORIG=$IFS
IFS="^"

# Initialize variables. bash is a bit limited, so we gotta do a "hack"
c=1
for a in `echo $@ | sed "s|\" \"|^|g"`; do
b[c]=$a
let c=c+1
done

IFS=$IFSORIG

# Give the variables some sensible names
IMDBDATE=${b[1]}
IMDBDOTFILE=${b[2]}
IMDBRELPATH=${b[3]}
IMDBDIRNAME=${b[4]}
IMDBURL=${b[5]}
IMDBTITLE=${b[6]}
IMDBGENRE=${b[7]}
IMDBRATING=${b[8]}
IMDBCOUNTRY=${b[9]}
IMDBLANGUAGE=${b[10]}
IMDBCERTIFICATION=${b[11]}
IMDBRUNTIME=${b[12]}
IMDBDIRECTOR=${b[13]}
IMDBBUSINESSDATA=${b[14]}
IMDBPREMIERE=${b[15]}
IMDBLIMITED=${b[16]}
IMDBVOTES=${b[17]}
IMDBSCORE=${b[18]}
IMDBNAME=${b[19]}
IMDBYEAR=${b[20]}
IMDBNUMSCREENS=${b[21]}
IMDBISLIMITED=${b[22]}
IMDBCASTLEADNAME=${b[23]}
IMDBCASTLEADCHAR=${b[24]}
IMDBTAGLINE=${b[25]}
IMDBPLOT=${b[26]}

############################################################

###### Let's start

# First, a couple of test to make sure we got the variables. These should be better.
if [ -z "$GLROOT" ]; then
 echo "config error. check variables."
 exit 0
fi
if [ -z "$GLFTPD_CONF" ]; then
 echo "config error. check variables."
 exit 0
fi
if [ -z "$NUKE_LOGFILE" ] && [ -z "$NUKE_WARN_MSG" ]; then
 if [ -z "`ls -la $GLROOT/bin/nuker | grep "-" | awk '{print $1}' | tr -d 'rwx-'`" ]; then
  echo "config error. check variables. the 'nuker' binary is not +s."
  exit 0
 fi
 if [ ! `ls -lan $GLROOT/bin/nuker | awk '{print $3}'` -eq 0 ]; then
  echo "config error. the 'nuker' binary is not owned by root."
  exit 0
 fi
 GL_DATAPATH="`cat $GLFTPD_CONF | grep -e "^datapath" | awk '{print $2}'`"
 if [ -z "$GL_DATAPATH" ]; then
  GL_DATAPATH="/ftp-data"
 fi
 if [ ! -e $GLROOT$GL_DATAPATH/users/$NUKER_PERSON ]; then
  echo "config error. check variables. could not find $NUKER_PERSON in list of users."
  exit 0
 fi
fi
if [ ! -z "$NUKE_LOGFILE" ]; then
 if [ ! -e $NUKE_LOGFILE ]; then
  touch $NUKE_LOGFILE || { 
   echo "config error. could not create $NUKE_LOGFILE."; exit 0;
  };
  chmod 777 $NUKE_LOGFILE || {
   echo "config error. could not chmod $NUKE_LOGFILE."; exit 0;
  };
 fi
 if [ ! -w $NUKE_LOGFILE ]; then
  echo "config error. unable to write to $NUKE_LOGFILE."; exit 0;
 fi
fi
if [ ! -z "$NUKE_WARN_FILE" ] && [ ! -z"$NUKE_WARN_MSG" ]; then
 if [ ! -w $GLROOT/$NUKE_WARN_FILE ]; then
  echo "config error. unable to write to $NUKE_WARN_FILE."; exit 0
 fi
fi

# Let's check to see if this script is run independently
if [ -z "$IMDBRELPATH" ]; then
 echo "Looks like you've run this as a standalone script."
 echo "Please look at the docs to see how to implement it."
 echo "FYI, the script's setup looks okay."
 exit 0
fi

# finally, let's see if the release still exists. Maybe it's already been
# moved by a different script?
if [ ! -e "$GLROOT/$IMDBRELPATH" ]; then
 exit 0
fi

##### From here on I will assume the needed bins exists, and the correct permissions
##### are set. The above should've catched most of such errors.

# First, let's make sure the variables we use are non-empty.
if [ -z "`echo "$IMDBSCORE" | tr '. ' '\n' | grep -v "^$" | head -n 1`" ]; then
 IMDBSCORE=0
fi
if [ -z "`echo "$IMDBVOTES" | tr -cd '0-9'`" ]; then
 IMDBVOTES=0
fi
if [ -z "`echo "$IMDBNUMSCREENS" | tr -cd '0-9'`" ]; then
 IMDBNUMSCREENS=0
fi
if [ -z "`echo "$IMDBYEAR" | tr -cd '0-9'`" ]; then
 if [ $NUKE_SAFEGUARD -ne 0 ]; then
  IMDBYEAR=0
 else
  exit 0
 fi
fi

# Let's do a quick test to see if the release should be nuked
NUKE_REASON=""
if [ `echo "$IMDBSCORE" | tr '. ' '\n' | grep -v "^$" | head -n 1` -lt $MIN_SCORE ]; then
 NUKE_REASON="$MIN_SCORE_MSG"
fi
if [ `echo "$IMDBVOTES" | tr -cd '0-9'` -lt $NUKE_VOTES ]; then
 NUKE_REASON="$NUKE_VOTES_MSG"
fi
if [ `echo "$IMDBYEAR" | tr -cd '0-9'` -lt $NUKE_YEAR ]; then
 NUKE_REASON="$NUKE_YEAR_MSG"
fi
if [ `echo "$IMDBNUMSCREENS" | tr -cd '0-9'` -lt $NUKE_SCREENS ]; then
 NUKE_REASON="$NUKE_SCREENS_MSG"
fi

# If there's no reason to nuke, let's just exit
if [ -z "$NUKE_REASON" ]; then
 exit 0
fi

# Before we nuke it, let's check for reasons not to.
# First, let's make sure we're not in an affil/pre/group/private dir

if [ ! -z "$BOTEXEMPT" ]; then
 for EXEMPT in $BOTEXEMPT; do
  if [ ! -z "`echo "$IMDBRELPATH" | grep -e "$EXEMPT"`" ]; then
   exit 0
  fi
 done
fi

# Let's see if the releasedir was created by someone unnukable

if [ ! -z "$NO_NUKE_USER" ]; then
 USER_ID=`ls -lan "$GLROOT/$IMDBRELPATH" | grep -e "\ \.$" | awk '{print $3}'`
 USER_NAME="`cat $GLROOT/etc/passwd | tr -d ' ' | tr ':' ' ' | awk '{print $1,$3}' | grep -e "\ $USER_ID$" | awk '{print $1}'`"
 if [ ! -z "`echo "$NO_NUKE_USER" | grep $USER_NAME`" ]; then
  exit 0
 fi
fi

# Perhaps it was uploaded by someone in a special group?

if [ ! -z "$NO_NUKE_GROUP" ]; then
 GROUP_ID=`ls -lan "$GLROOT/$IMDBRELPATH" | grep -e "\ \.$" | awk '{print $4}'`
 GROUP_NAME="`cat $GLROOT/etc/group | tr -d ' ' | sed "s|::|:vomit:|g" | tr ':' ' ' | awk '{print $1,$3}' | grep -e "\ $GROUP_ID$" | awk '{print $1}'`"
 if [ ! -z "`echo "$NO_NUKE_GROUP" | grep $GROUP_NAME`" ]; then
  exit 0
 fi
fi

# Maybe it's one of the affils doing the upload?

if [ ! -z "$NO_NUKE_AFFIL_DIR" ]; then
 AFFIL_ID=`ls -lan "$GLROOT/$IMDBRELPATH" | grep -e "\ \.$" | awk '{print $4}'`
 AFFIL_NAME="`cat $GLROOT/etc/group | tr -d ' ' | sed "s|::|:vomit:|g" | tr ':' ' ' | awk '{print $1,$3}' | grep -e "\ $AFFIL_ID$" | awk '{print $1}'`"
 for AFFIL_DIR in $NO_NUKE_AFFIL_DIR; do
  if [ -d $GLROOT/$AFFIL_DIR ]; then
   if [ ! -z "`ls -lF $GLROOT/$AFFIL_DIR | grep -e "/" | grep -e "\ $AFFIL_NAME/"`" ]; then
    exit 0
   fi
  fi
 done
fi

# or maybe the releasegroup is someone we like?

if [ ! -z "$NO_NUKE_RELGROUP" ]; then
 RELGROUP="`echo "$IMDBDIRNAME" | tr '-' '\n' | grep -v "^$" | tail -n 1`"
 if [ ! -z "`echo "$NO_NUKE_RELGROUP" | grep -e "$RELGROUP"`" ]; then
  exit 0
 fi
fi

# how about the location of the release?

if [ ! -z "$NO_NUKE_DIR" ]; then
 for DIR_NAME in $NO_NUKE_DIR; do
  if [ ! -z "`echo "$IMDBRELPATH" | grep -e "$DIR_NAME"`" ]; then
   exit 0
  fi
 done
fi

# Release is a candidate for nuking. Now all that needs be done is either
# nuke it, or log it.

if [ ! -z "$NUKE_LOGFILE" ]; then
 echo "$IMDBRELPATH $MULTIPLIER $NUKE_REASON" >> $NUKE_LOGFILE
else
 if [ -z "$NUKE_WARN_MSG" ]; then
  $GLROOT/bin/nuker -r $GLFTPD_CONF -N $NUKER_PERSON -n {$IMDBRELPATH}/ $MULTIPLIER $NUKE_REASON >/dev/null 2>&1
 else
  NUKE_WARN_MSG="`echo $NUKE_WARN_MSG | sed "s%RELNAME%$IMDBDIRNAME%g" | sed "s%REASON%$NUKE_REASON%g" | sed "s%MOVIENAME%$IMDBNAME%g" | sed "s%BOLD%$BOLD%g"`" 
  echo "$DATE $NUKE_WARN_TRIGGER \"$IMDBRELPATH\" \"$NUKE_WARN_MSG\"" >> $NUKE_WARN_FILE
 fi
fi

# You should always exit with a 0 - the parent won't give a crap anyway,
# but just to make sure...
exit 0

==> psxc-imdb_v2.2.tgz: psxc-imdb_v2.2/addons/psxc-imdb-nuker.sh <==
#!/bin/bash

# psxc-imdb-nuker
# this script will nuke releases based on imdb score.
#####################################################
#
# This script first appeared with psxc-imdb v2.0k

# Config
########
# Any of the following variables put in psxc-imdb.conf will override what is
# put in here. The only "needed" variable is the variable describing the path
# to psxc-imdb.conf. Fyi.
# After you're done configging, run the script from shell. It will test a
# few variables/settings and report back to you.
#############################################################################

# Version number. No need to change
VERSION=2.2

# The location of psxc-imdb.conf. This is the full path.
IMDB_CONF=/glftpd/etc/psxc-imdb.conf
#IMDB_CONF=/glftpd/bin/psxc-imdb.conf

# What imdb score should be the minimum *allowed* on site? For now no decimals
# is allowed.
MIN_SCORE=5
#MIN_SCORE=6

# Nuke message for score nukes.
MIN_SCORE_MSG="Too low iMDB score"

# On the other hand, you can choose to nuke the release if there is less than
# a certain number of votes on the movie, no matter how high it scored.
NUKE_VOTES=10
#NUKE_VOTES=0

# Nuke message for votes nuke.
NUKE_VOTES_MSG="Too few votes on iMDB"

# Some sites allow only movies after a certain year. Here's an option to
# auto-nuke movies older than the following year.
NUKE_YEAR=2000
#NUKE_YEAR=0

# Nuke message for year nukes.
NUKE_YEAR_MSG="Movie is too old"

# Some people may want to nuke limited releases. Or only allow movies with
# a certain number of screens. Here's a way to do so. Less than the following
# number will be nuked.
NUKE_SCREENS=100
#NUKE_SCREENS=0

# Nuke message for screens nuke.
NUKE_SCREENS_MSG="Limited movies not allowed."

# What should be the multiplier of these nukes?
MULTIPLIER=3
#MULTIPLIER=2

# You can select a number of groups not to nuke here (affils etc). Separate
# the groupname with a space.
NO_NUKE_GROUP="siteops affils"
#NO_NUKE_GROUP=""

# You can also exclude a number of people from being nuked. Separate list by
# a space.
NO_NUKE_USER="sitop pr0nking"
#NO_NUKE_USER=""

# You can also include dirs here which holds the name of all affils. This is
# perhaps the best option as you can add and remove affils dynamically without
# editing this config all the time. The listed groupnames must be directories.
# The dirs listed must be relative to GLROOT in psxc-imdb.conf
NO_NUKE_AFFIL_DIR="/site/AFFILS /site/GROUPS"
#NO_NUKE_AFFIL_DIR=""

# You can also enter a list of groups which release movies you never want to
# nuke, no matter how bad score, votes etc.
NO_NUKE_RELGROUP="CPY QSP"
#NO_NUKE_RELGROUP=""

# If you wish to keep all releases uploaded in certain dirs, enter them here.
# Paths are relative to GLROOT
NO_NUKE_DIR="/site/ARCHIVE /site/PRIVATE"
#NO_NUKE_DIR=""

# The location of glftpd.conf. This is the full path.
GLFTPD_CONF=/glftpd/etc/glftpd.conf
#GLFTPD_CONF=/etc/glftpd.conf

# Since nuking require root privileges, or that the nuker binary has the set-UID-bit
# set (chmod +s /glftpd/bin/nuker), You can instead of performing the nuke in this
# script log the offending dirs to a file. Then you can use a crontab'ed script to
# do the actual nuking, or whatever else you prefer.
# Either set the name of a logfile here, or set this empty to do nukes on the fly.
# Also check NUKE_WARN below.
# The syntax of the logfile is as follows:
# <dir relative to $GLROOT> <multiplier> <message>
#NUKE_LOGFILE="/glftpd/ftp-data/logs/imdb-nukes.log"
NUKE_LOGFILE=""

# Putting the following variables non-empty will stop nuke on the fly - instead, a
# msg will be put in a logfile, using standard glftpd.log format.
# This warning will not stop any logging done to a file in NUKE_LOGFILE
# The file is *not* relative to GLROOT.
# The message uses the following keywords:
# RELNAME   - name of the release directory
# REASON    - the reason why the release will be nuked. See nuke msg's above.
# MOVIENAME - Name of the movie.
# BOLD      - Bold characters on/off.
NUKE_WARN_FILE=/glftpd/ftp-data/logs/glftpd.log
#NUKE_WARN_FILE=""

NUKE_WARN_MSG="[ BOLDIMDB NUKEWARNINGBOLD ] : [ BOLDRELNAMEBOLD ] is a nukee - REASON"
#NUKE_WARN_MSG=""

NUKE_WARN_TRIGGER="UPDATE:"
#NUKE_WARN_TRIGGER=""

# In case you do nuking on the fly, what user should be the one doing the nuking?
# This has got to be a valid user in glftpd's password list.
NUKER_PERSON="sitebot"

# Sometimes an imdb lookup fails. For some moderate protection against this (you
# do not wish to autonuke a release if the imdb script haven't found the data)
# To safeguard from this you should keep the following variable set to 1
NUKE_SAFEGUARD=1
#NUKE_SAFEGUARD=0

# End of config
####################################################################################

# Let's load some variables from psxc-imdb.conf
. $IMDB_CONF

####################################################################################
# The following grabs exported variables. The code is taken from psxc-imdb-parser.sh
# found in the extras/ dir.

IFSORIG=$IFS
IFS="^"

# Initialize variables. bash is a bit limited, so we gotta do a "hack"
c=1
for a in `echo $@ | sed "s|\" \"|^|g"`; do
b[c]=$a
let c=c+1
done

IFS=$IFSORIG

# Give the variables some sensible names
IMDBDATE=${b[1]}
IMDBDOTFILE=${b[2]}
IMDBRELPATH=${b[3]}
IMDBDIRNAME=${b[4]}
IMDBURL=${b[5]}
IMDBTITLE=${b[6]}
IMDBGENRE=${b[7]}
IMDBRATING=${b[8]}
IMDBCOUNTRY=${b[9]}
IMDBLANGUAGE=${b[10]}
IMDBCERTIFICATION=${b[11]}
IMDBRUNTIME=${b[12]}
IMDBDIRECTOR=${b[13]}
IMDBBUSINESSDATA=${b[14]}
IMDBPREMIERE=${b[15]}
IMDBLIMITED=${b[16]}
IMDBVOTES=${b[17]}
IMDBSCORE=${b[18]}
IMDBNAME=${b[19]}
IMDBYEAR=${b[20]}
IMDBNUMSCREENS=${b[21]}
IMDBISLIMITED=${b[22]}
IMDBCASTLEADNAME=${b[23]}
IMDBCASTLEADCHAR=${b[24]}
IMDBTAGLINE=${b[25]}
IMDBPLOT=${b[26]}

############################################################

###### Let's start

# First, a couple of test to make sure we got the variables. These should be better.
if [ -z "$GLFTPD_CONF" ]; then
 echo "config error. check variables. (glftpd.conf)"
 exit 0
fi
if [ -z "$NUKE_LOGFILE" ] && [ -z "$NUKE_WARN_MSG" ]; then
 if [ -z "`ls -la $GLROOT/bin/nuker | grep "-" | awk '{print $1}' | tr -d 'rwx-'`" ]; then
  echo "config error. check variables. the 'nuker' binary is not +s."
  exit 0
 fi
 if [ ! `ls -lan $GLROOT/bin/nuker | awk '{print $3}'` -eq 0 ]; then
  echo "config error. the 'nuker' binary is not owned by root."
  exit 0
 fi
 GL_DATAPATH="`cat $GLFTPD_CONF | grep -e "^datapath" | awk '{print $2}'`"
 if [ -z "$GL_DATAPATH" ]; then
  GL_DATAPATH="/ftp-data"
 fi
 if [ ! -e $GLROOT$GL_DATAPATH/users/$NUKER_PERSON ]; then
  echo "config error. check variables. could not find $NUKER_PERSON in list of users."
  exit 0
 fi
fi
if [ ! -z "$NUKE_LOGFILE" ]; then
 if [ ! -e $NUKE_LOGFILE ]; then
  touch $NUKE_LOGFILE || { 
   echo "config error. could not create $NUKE_LOGFILE."; exit 0;
  };
  chmod 777 $NUKE_LOGFILE || {
   echo "config error. could not chmod $NUKE_LOGFILE."; exit 0;
  };
 fi
 if [ ! -w $NUKE_LOGFILE ]; then
  echo "config error. unable to write to $NUKE_LOGFILE."; exit 0;
 fi
fi
if [ ! -z "$NUKE_WARN_FILE" ] && [ ! -z"$NUKE_WARN_MSG" ]; then
 if [ ! -w $GLROOT/$NUKE_WARN_FILE ]; then
  echo "config error. unable to write to $NUKE_WARN_FILE."; exit 0
 fi
fi

# Let's check to see if this script is run independently
if [ -z "$IMDBRELPATH" ]; then
 echo "Looks like you've run this as a standalone script."
 echo "Please look at the docs to see how to implement it."
 echo "FYI, the script's setup looks okay."
 exit 0
fi

# finally, let's see if the release still exists. Maybe it's already been
# moved by a different script?
if [ ! -e "$GLROOT/$IMDBRELPATH" ]; then
 exit 0
fi

##### From here on I will assume the needed bins exists, and the correct permissions
##### are set. The above should've catched most of such errors.

# First, let's make sure the variables we use are non-empty.
if [ -z "`echo "$IMDBSCORE" | tr '. ' '\n' | grep -v "^$" | head -n 1`" ]; then
 if [ $NUKE_SAFEGUARD -ne 0 ]; then
  IMDBSCORE=0
 else
  IMDBSCORE=10
 fi
fi
if [ -z "`echo "$IMDBVOTES" | tr -cd '0-9'`" ]; then
 if [ $NUKE_SAFEGUARD -ne 0 ]; then
  IMDBVOTES=0
 else
  IMDBVOTES=9999999
 fi
fi
if [ -z "`echo "$IMDBNUMSCREENS" | tr -cd '0-9'`" ]; then
 IMDBNUMSCREENS=0
fi
if [ -z "`echo "$IMDBYEAR" | tr -cd '0-9'`" ]; then
 if [ $NUKE_SAFEGUARD -ne 0 ]; then
  IMDBYEAR=0
 else
  exit 0
 fi
fi

# Let's do a quick test to see if the release should be nuked
NUKE_REASON=""
if [ `echo "$IMDBSCORE" | tr '. ' '\n' | grep -v "^$" | head -n 1` -lt $MIN_SCORE ]; then
 NUKE_REASON="$MIN_SCORE_MSG"
fi
if [ `echo "$IMDBVOTES" | tr -cd '0-9'` -lt $NUKE_VOTES ]; then
 NUKE_REASON="$NUKE_VOTES_MSG"
fi
if [ `echo "$IMDBYEAR" | tr -cd '0-9'` -lt $NUKE_YEAR ]; then
 NUKE_REASON="$NUKE_YEAR_MSG"
fi
if [ `echo "$IMDBNUMSCREENS" | tr -cd '0-9'` -lt $NUKE_SCREENS ]; then
 NUKE_REASON="$NUKE_SCREENS_MSG"
fi

# If there's no reason to nuke, let's just exit
if [ -z "$NUKE_REASON" ]; then
 exit 0
fi

# Before we nuke it, let's check for reasons not to.
# First, let's make sure we're not in an affil/pre/group/private dir

if [ ! -z "$BOTEXEMPT" ]; then
 for EXEMPT in $BOTEXEMPT; do
  if [ ! -z "`echo "$IMDBRELPATH" | grep -e "$EXEMPT"`" ]; then
   exit 0
  fi
 done
fi

# Let's see if the releasedir was created by someone unnukable

if [ ! -z "$NO_NUKE_USER" ]; then
 USER_ID=`ls -lan "$GLROOT/$IMDBRELPATH" | grep -e "\ \.$" | awk '{print $3}'`
 USER_NAME="`cat $GLROOT/etc/passwd | tr -d ' ' | tr ':' ' ' | awk '{print $1,$3}' | grep -e "\ $USER_ID$" | awk '{print $1}'`"
 if [ ! -z "`echo "$NO_NUKE_USER" | grep $USER_NAME`" ]; then
  exit 0
 fi
fi

# Perhaps it was uploaded by someone in a special group?

if [ ! -z "$NO_NUKE_GROUP" ]; then
 GROUP_ID=`ls -lan "$GLROOT/$IMDBRELPATH" | grep -e "\ \.$" | awk '{print $4}'`
 GROUP_NAME="`cat $GLROOT/etc/group | tr -d ' ' | sed "s|::|:vomit:|g" | tr ':' ' ' | awk '{print $1,$3}' | grep -e "\ $GROUP_ID$" | awk '{print $1}'`"
 if [ ! -z "`echo "$NO_NUKE_GROUP" | grep $GROUP_NAME`" ]; then
  exit 0
 fi
fi

# Maybe it's one of the affils doing the upload?

if [ ! -z "$NO_NUKE_AFFIL_DIR" ]; then
 AFFIL_ID=`ls -lan "$GLROOT/$IMDBRELPATH" | grep -e "\ \.$" | awk '{print $4}'`
 AFFIL_NAME="`cat $GLROOT/etc/group | tr -d ' ' | sed "s|::|:vomit:|g" | tr ':' ' ' | awk '{print $1,$3}' | grep -e "\ $AFFIL_ID$" | awk '{print $1}'`"
 for AFFIL_DIR in $NO_NUKE_AFFIL_DIR; do
  if [ -d $GLROOT/$AFFIL_DIR ]; then
   if [ ! -z "`ls -lF $GLROOT/$AFFIL_DIR | grep -e "/" | grep -e "\ $AFFIL_NAME/"`" ]; then
    exit 0
   fi
  fi
 done
fi

# or maybe the releasegroup is someone we like?

if [ ! -z "$NO_NUKE_RELGROUP" ]; then
 RELGROUP="`echo "$IMDBDIRNAME" | tr '-' '\n' | grep -v "^$" | tail -n 1`"
 if [ ! -z "`echo "$NO_NUKE_RELGROUP" | grep -e "$RELGROUP"`" ]; then
  exit 0
 fi
fi

# how about the location of the release?

if [ ! -z "$NO_NUKE_DIR" ]; then
 for DIR_NAME in $NO_NUKE_DIR; do
  if [ ! -z "`echo "$IMDBRELPATH" | grep -e "$DIR_NAME"`" ]; then
   exit 0
  fi
 done
fi

# Release is a candidate for nuking. Now all that needs be done is either
# nuke it, or log it.

if [ ! -z "$NUKE_LOGFILE" ]; then
 echo "$IMDBRELPATH $MULTIPLIER $NUKE_REASON" >> $NUKE_LOGFILE
else
 if [ -z "$NUKE_WARN_MSG" ]; then
  $GLROOT/bin/nuker -r $GLFTPD_CONF -N $NUKER_PERSON -n {$IMDBRELPATH}/ $MULTIPLIER $NUKE_REASON >/dev/null 2>&1
 else
  NUKE_WARN_MSG="`echo $NUKE_WARN_MSG | sed "s%RELNAME%$IMDBDIRNAME%g" | sed "s%REASON%$NUKE_REASON%g" | sed "s%MOVIENAME%$IMDBNAME%g" | sed "s%BOLD%$BOLD%g"`" 
  echo "$DATE $NUKE_WARN_TRIGGER \"$IMDBRELPATH\" \"$NUKE_WARN_MSG\"" >> $NUKE_WARN_FILE
 fi
fi

# You should always exit with a 0 - the parent won't give a crap anyway,
# but just to make sure...
exit 0
